@@ -6,7 +6,7 @@ use Catmandu::AlephX;
 use Data::Dumper;
 use open qw(:std :utf8);
 
-my $aleph = Catmandu::AlephX->new(url => "http://aleph.ugent.be/X");
+my $aleph = Catmandu::AlephX->new(url => "http://borges1.ugent.be/X");
 
 my($library,$item_barcode)=("usm50","293");
 my $readitem = $aleph->read_item(library=>$library,item_barcode=>$item_barcode);
@@ -14,4 +14,4 @@ if($readitem->is_success){
   print Dumper($readitem->z30);
 }else{
   say STDERR join('',@{$readitem->errors});
-} 
+}
