@@ -13,7 +13,7 @@ if(is_string($file) && -f $file){
   open STDIN,"<",$file or die($!);
 }
 my $importer = Catmandu::Importer::MARC->new(type => "ALEPHSEQ");
-my $bag = Catmandu::Store::AlephX->new(url => "http://aleph.ugent.be/X",username => "t",password => "t")->bag();
+my $bag = Catmandu::Store::AlephX->new(url => "http://borges1.ugent.be/X",username => "t",password => "t")->bag();
 
 $importer->each(sub{
   my $r = shift;
