@@ -3,7 +3,7 @@ use Catmandu::Sane;
 use Catmandu::Util qw(:check :is);
 use Moo;
 
-our $VERSION = "1.072";
+our $VERSION = "1.073";
 
 with('Catmandu::AlephX::Response');
 
@@ -34,7 +34,7 @@ sub parse {
   __PACKAGE__->new(
     session_id => $xpath->findvalue("/$op/session-id"),
     errors => $class->parse_errors($xpath),
-    z30 => $z30[0],
+    z30 => $z30[0] // +{},
     content_ref => $str_ref
   );
 }
